# prisma_helpers
helpers functions for interacting with prisma api using python async libraries asyncio and aiohttp

documentation is on its way :-) 

# push to pypi 
- install wheel: `pip install wheel`
- Follow instructions here: https://packaging.python.org/tutorials/packaging-projects/
- ... with some modifications: `python setup.py sdist`
- `twine upload dist/`


